/***********************************************************************/
/*                            NLS messages                             */
/*                                                                     */
/* This procedure contains all the message strings that should be      */
/* translated for NLS support.                                         */
/*                                                                     */
/* This procedure is called by RPLSETD.CMD.  It stacks all the         */
/* message strings in the standard rexx queue in FIFO order.           */
/* When control is return to RPLSETD.CMD, RPLSETD will pull the        */
/* message strings from the queue and assign them to the appropriate   */
/* message variable.                                                   */
/*                                                                     */
/* Notes:The %1, %2, etc. strings represent dynamic data fields that   */
/*       are filled in when the message is displayed.  Do not          */
/*       translate the %1, %2, etc. fields.                            */
/*                                                                     */
/*       The %Tnn and %Inn (nn is a number) strings in the syntax      */
/*       help messages represent special formatting control data and   */
/*       should not be translated.  The %Tnn represents number of      */
/*       blanks that should be prepended to the start of the message.  */
/*       The %Inn represents the indentation value to use if a line    */
/*       has to be split across 1 or more following lines.             */
/*                                                                     */
/*       The 'CRLF,' sequence that ends some lines represents          */
/*       formatting control (new line) and should not be translated.   */
/***********************************************************************/
parse arg msgtype

/* do not translate the following line */
CRLF = '0A0D'X

/* translate all message strings that follow */
/* message prefix strings */
errprefix = 'ERROR: '
unknown = 'UNKNOWN'

/* start of error and informational messages */
message.1 = 'Missing keyword in '
message.2 = 'Client or Clientlist and DisplayDriver, Bustype, or swaptarget',
            'are required.'
message.3 = 'HISTORY LOG: '
message.4 = 'Unable to open the Logfile '
message.5 = 'The display driver %1.DLL is not installed in the Remote IPL',
            'directory %2.'
message.6 = 'Invalid Bus type specified.'
message.7 = 'Error detected.  Check log file: '
message.8 = 'The version of LAN Server is prior to Version 2.0.'
message.9 = ' is using OS/2 directory %1.  The version of',
            'OS/2 in the %1 directory tree is %2.',
            'This version of OS/2 does not support 32 bit display drivers.'
message.10 = ' could not be found.'
message.11 = ' copy of %1 was updated.'
message.12 = ' copy of %1 was not updated.'
message.13 = '.FIT was updated.'
message.14 = '.FIT was not updated.'
message.15 = ' copy of OS2INI.20 was not updated.  Either the file did' CRLF,
             'not exist or the Remote client is still powered up and has the' CRLF,
             'file locked.  Processing terminated for '
message.16 = 'Not able to upgrade the format of file %1\IBMCOM\%2\CONFIG.20.'
message.17 = 'The PATH environment variable does not contain a reference to' CRLF,
             '\IBMLAN.  Either LAN Server 2.0 is not installed or the PATH' CRLF,
             'variable has been modified to remove \IBMLAN references.  If' CRLF,
             'LAN Server 2.0 is installed, use the SET command to update the' CRLF,
             'PATH variable to specify the path for the directory \IBMLAN\NETPROG' CRLF,
             'and then rerun RPLSETD.CMD.'
message.18 = 'RPLDIR parameter was not found in IBMLAN.INI.'
message.19 = 'Invalid display driver specified.'
message.20 = 'The option %1 is not a valid option.'
message.21 = 'The following RPLSETD command syntax is not valid:' CRLF,
             '  RPLSETD  %1 %2 %3 %4 %5 %6 %7 %8'
message.22 = ' 'CRLF 'Press the Enter key for next screen.'
message.23 = 'The RPLMIG21.CMD procedure has not been run to upgrade Remote IPL' CRLF,
             'to support OS/2 2.1.  Run RPLMIG21.CMD prior to using RPLSETD.CMD.'
message.24 = ' is not a valid RIPL client name.'
message.25 = ' is not a valid response file entry.  Entry was ignored.'
message.26 = '/N (NEWOS2DIR) must be specified when /O (CURRENTOS2DIR) is specified.'
message.27 = ' workstation record in RPL.MAP was updated.'
message.28 = ' workstation record in RPL.MAP could not be updated.'
message.29 = 'Invalid swaptarget specified.'
message.30 = '/C (CLIENT or CLIENTLIST) is a required parameter.'
message.31 = 'At least one of following must also be specified: ' CRLF,
             '/D (DISPLAYDRIVER),/N (NEWSO2DIR), /B (BUSTYPE),' ,
             'and/or /S (SWAPTARGET).'
message.32 = ' is an OS/2 2.1 client.  Conversion to a previous OS/2 version',
             'is not allowed.'
message.33 = 'The /O (CURRENTOS2) value %1 does not match the operating system ',
             'type of client %3.  The operating system type of %3 is %2.'
message.34 = 'The client copy of the WINOS2 *.INI and *.GRP files have been replaced',
             'with the OS/2 2.1 version of those files.'
message.35 = ' is an OS/2 1.3.2 RIPL client.  1.3.2 RIPL clients cannot be',
             'upgraded.'
message.36 = 'DEFALT21 is a reserved name.  RPLSETD can not update DEFALT21.'
message.37 = ''
message.38 = ''
message.39 = ''

/* start of syntax help messages */
/* %Tnn, %Inn, and CRLF strings are format controls, do not translate them */
message.40 = '%T10 %I10 ' ,
             'RPLSETD   [? | /H] /C:client[,client2,client3,...]  [/D:driver] ',
             '[/O:current_OS2]  [/N:new_OS2] [/L:Logfile]   [/R:Response_file]'CRLF,
             ' '
message.41 = '%T10 %I8 ' ,
             'where ? or /H is a request for this help panel.  If specified, it must',
             'be first parameter.'CRLF,
             ' '
message.42 = '%T16 %I3 ' ,
             '/C:client (CLIENT or CLIENTLIST) is the name of one or more OS/2',
             'Remote IPL client workstations.  If more than one client is',
             'specified, each client name must be separated with a comma.',
             'Imbedded blanks are not allowed.  Multiple CLIENT and/or',
             'CLIENTLIST parameters are allowed in the response file.',
             '/C and at least one of the following must be specified:' CRLF,
             '/D, /N, /B, or /S.'CRLF,
             ' '
message.43 = '%T16 %I3 ',
             '/D:driver (DISPLAYDRIVER) is the new display type for the client',
             'definition.  The following display types are valid:' CRLF,
             '%T21 %I13 ',
             'IBMVGA32  - 32 bit VGA display driver' CRLF,
             '%T21 %I13 ',
             'IBMXGA32  - 32 bit XGA display driver' CRLF,
             '%T21 %I13 ',
             'IBM8514   - 16 bit 8514 display driver(2.0+SP or 2.00.1)' CRLF,
             '%T33 ',
             '32 bit 8514 display driver(2.1)' CRLF,
             ' '
message.44 = '%T16 %I3 ',
             '/O:current_OS2 (CURRENTOS2DIR) is the root directory (under',
             '\IBMLAN\RPL) for the current OS/2 2.0 operating system that',
             'the client is booting.  This parameter is case sensitive.',
             'If /O is not specified, the OS/2 operating system currently',
             'being used by the client is determined by reading the',
             'client.FIT file.  /O or /N should only be specified',
             'when the version of the client operating system should be',
             'changed.  If /O is specified, then /N must also be specified.'CRLF,
             ' '
message.45 = '%T16 %I3 ',
             '/N:new_OS2 (NEWOS2DIR) is the root directory (under \IBMLAN\RPL) for',
             'switched to.  This parameter is case sensitive.  The default',
             'is OS2.21.  /O or /N should only be specified when the',
             'version of the client operating system should be changed.'CRLF,
             ' '
message.46 = '%T16 %I3 ',
             '/B:Bustype (BUSTYPE) is the type of I/O bus used by the RIPL client',
             'machine.  Valid types are: '  CRLF,
             '%T21 %I7 ',
             'MCA  - Micro-channel (IBM PS/2)' CRLF,
             '%T21 %I7 ',
             'ISA  - AT compatable' CRLF,
             '%T21 %I7 ',
             'EISA - AT compatable' CRLF,
             ' '
message.47 = '%T16 %I3 ',
             '/S:Swaptarget (SWAPTARGET) is an indicator of where the SWAPPER.DAT',
             'file and the WINOS2 PagingFile will reside:  Valid values are:' CRLF,
             '%T21 %I4 ',
             'L - file will reside on local hardfile of RIPL client' CRLF,
             '%T21 %I4 ',
             'S - file will reside on RIPL server' CRLF,
             ' '
message.48 = '%T16 %I3 ',
             '/L:Logfile is the fully qualified name of a file to ',
             'which all messages and errors are to be logged.  If',
             'logfile is specified, no messages or errors will be',
             'displayed on the screen.' CRLF,
             ' '
message.49 = '%T16 %I3 ',
             '/R:Response_file is the fully qualified name of a file',
             'that contains all the inputs in keyword form(Keyword=value). ',
             'The keywords are indicated above in () following the /X:',
             'syntax.  If this parameter is specified, all other command',
             'line parameters except Logfile are ignored.  It is',
             'recommended that the Logfile parameter be specified',
             'whenever the Response_file parameter is used.' CRLF,
             ' '
message.50 = '%T4 ',
             'Note: The following conditions must be meet before running RPLSETD:' CRLF,
             '%T10 %I3 ',
             '1. The Remoteboot Service should be stopped.' CRLF,
             '%T10 %I3 ',
             '2. The Remote IPL workstations to be upgraded must do a',
             'System Shutdown.'CRLF,
             '%T10 %I3 ',
             '3. Remote IPL workstations to be upgraded can not have a session',
             'with the RIPL server.  If necessary, force the session to' ,
             'disconnect using the server full screen interface. '

/* start of comment strings used by RPLUCC20.CMD */
message.60 = 'REM Use the following 7 statements for workstations with XGA displays:'
message.61 = 'REM Use the following 5 statements for workstations with 8514/A adapters:'
message.62 = 'REM Use the following 4 statements for workstations with EGA displays:'
message.63 = 'REM Use the following 4 statements for workstations with VGA displays:'

/* end of message strings */

   /* make sure queue is empty */
   do while queued()
      Pull dummy
   end

   If msgtype = 1 Then Do
      /* push all message strings for RPLSETD.CMD into queue (FIFO)*/
      queue errprefix
      queue unknown

      do i = 1 to 50
         queue message.i
      end
   end
   else If msgtype = 2 Then Do
      /* push strings for RPLUCC20.CMD into queue (FIFO) */
      do i = 60 to 63
         queue message.i
      end
   end
return
